<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>BtInfoDialog</name>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="116"/>
        <source>New Task</source>
        <translation>Task nwin</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="146"/>
        <source>Total </source>
        <translation>Total </translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="152"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="399"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="408"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="461"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="490"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="519"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="547"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="597"/>
        <source>%1 files selected, %2</source>
        <translation>%1 filas seltan, %2</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="178"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="185"/>
        <source>Videos</source>
        <translation>Videoz</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="192"/>
        <source>Pictures</source>
        <translation>Tiflas</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="199"/>
        <source>Music</source>
        <translation>Muzik</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="206"/>
        <source>Others</source>
        <translation>Tawer</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="227"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="622"/>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="665"/>
        <source>Available:</source>
        <translation>Wafawal:</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="245"/>
        <source>Change download folder</source>
        <translation>Changed faldet tifawal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="253"/>
        <source>Download Now</source>
        <translation>Tifawal 3s</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="298"/>
        <source>Name</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="300"/>
        <source>Type</source>
        <translation>Tiflas</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="301"/>
        <source>Size</source>
        <translation>Gad</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="380"/>
        <source>Insufficient disk space, please change the download folder</source>
        <translation>Dadlad ladiskin, 3ni changed faldet tifawal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/btinfodialog.cpp" line="380"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CreateTaskWidget</name>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="113"/>
        <source>New Task</source>
        <translation>Task nwin</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="119"/>
        <source>Please enter one URL per line</source>
        <translation>3ni sirti URL 3li lline</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="137"/>
        <source>Enter download links or drag a torrent file here</source>
        <translation>Sirti llinks tifawal 3li 3aw, ya 3ni sirti faldet torrent 3li 3aw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="215"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="1072"/>
        <source>Total </source>
        <translation>Total </translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="221"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="766"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="800"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="833"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="866"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="899"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="932"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="964"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="1141"/>
        <source>%1 files selected, %2</source>
        <translation>%1 filas seltan, %2</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="234"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="240"/>
        <source>Videos</source>
        <translation>Wizyik</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="246"/>
        <source>Pictures</source>
        <translation>Fotografias</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="252"/>
        <source>Music</source>
        <translation>Muzik</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="258"/>
        <source>Others</source>
        <translation>Ammach</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="264"/>
        <source>Documents</source>
        <translation>Dokumenten</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="270"/>
        <source>Archives</source>
        <translation>Archiv</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="298"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="567"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="705"/>
        <source>Available:</source>
        <translation>Akwizit:</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="337"/>
        <source>Change download folder</source>
        <translation>Fasalit fen tafessil</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="353"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="361"/>
        <source>Select file</source>
        <translation>Sefi fil</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="375"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annule</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="382"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="402"/>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="420"/>
        <source>Choose Torrent File</source>
        <translation>Fasalit fil torrent</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="467"/>
        <source>Insufficient disk space, please change the download folder</source>
        <translation>Akwizit tami, tefessil fen fass</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="467"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/createtaskwidget.cpp" line="1246"/>
        <source>Network error, check your network and try later</source>
        <translation>Wadawt internet, tefessil fen internet yew iksusen amma tafessil aflan</translation>
    </message>
</context>
<context>
    <name>DiagnosticModel</name>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="292"/>
        <source>IPv6 support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="294"/>
        <source>DHT status</source>
        <translation>Statut DHT</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="296"/>
        <source>HTTP task</source>
        <translation>Task HTTP</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="298"/>
        <source>BT task</source>
        <translation>Task BT</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="300"/>
        <source>Magnet task</source>
        <translation>Task magnet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="302"/>
        <source>Network detection</source>
        <translation>Tafessil internet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="307"/>
        <source>Pass</source>
        <translation>Pess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="307"/>
        <source>Failed</source>
        <translation>Fasalit</translation>
    </message>
</context>
<context>
    <name>DiagnosticTool</name>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="89"/>
        <source>Result:</source>
        <translation>Resultat:</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/diagnostictool.cpp" line="91"/>
        <source>Diagnose Again</source>
        <translation>Tafessil aflan</translation>
    </message>
</context>
<context>
    <name>DownloadSettingWidget</name>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="59"/>
        <source>Full speed</source>
        <translation>Velya</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="62"/>
        <source>Downloaded files will be uploaded through P2P, 
which could help other users speed up the downloading, 
and it does not involve user privacy.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="70"/>
        <source>Limited speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="110"/>
        <source>Max. download speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="111"/>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="117"/>
        <source>KB/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="116"/>
        <source>Max. upload speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="122"/>
        <source>Limit period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="123"/>
        <source>to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="271"/>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="286"/>
        <source>The end time must be greater than the start time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="305"/>
        <source>Limited between 100-102400</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/downloadsettingwidget.cpp" line="327"/>
        <source>Limited between 16-5120</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileSavePathChooser</name>
    <message>
        <location filename="../src/src/ui/settings/filesavepathchooser.cpp" line="55"/>
        <source>Last used directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/filesavepathchooser.cpp" line="57"/>
        <source>Default directory</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HttpAdvancedSettingWidget</name>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="69"/>
        <source>Edit File Extensions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="75"/>
        <source>Edit Unmonitored Sites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="90"/>
        <source>Restore</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="102"/>
        <source>Cancel</source>
        <translation>Annule</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="108"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="163"/>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="167"/>
        <source>Separate file extensions by semicolons (;)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="173"/>
        <location filename="../src/src/ui/settings/httpadvancedsettingwidget.cpp" line="177"/>
        <source>Please enter one URL per line</source>
        <translation>3ni sirti URL 3li lline</translation>
    </message>
</context>
<context>
    <name>ItemDelegate</name>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="214"/>
        <source>Paused</source>
        <translation>Apsen</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="224"/>
        <source>Failed</source>
        <translation>Fasalit</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="235"/>
        <source>Waiting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="247"/>
        <source>Resources:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="251"/>
        <source>Time left </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/itemDelegate.cpp" line="400"/>
        <source>Duplicate name</source>
        <translation>T-ta7allum t-ta7allum</translation>
    </message>
</context>
<context>
    <name>ItemSelectionWidget</name>
    <message>
        <location filename="../src/src/ui/settings/itemselectionwidget.cpp" line="61"/>
        <source>Advanced</source>
        <translation>Adavans</translation>
    </message>
</context>
<context>
    <name>MainFrame</name>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="110"/>
        <source>Settings</source>
        <translation>Tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="114"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="115"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="340"/>
        <source>When completed</source>
        <translation>Amassar</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="116"/>
        <source>Shut down</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="118"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="120"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="348"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="615"/>
        <source>Exit</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="129"/>
        <source>Diagnostic tool</source>
        <translation>Taslaq tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="177"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="950"/>
        <source>No download tasks</source>
        <translation>Wen adawen tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="187"/>
        <source>Click + to create new task</source>
        <translation>Biski + liggasen tashbet tawwal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="207"/>
        <source>0 tasks</source>
        <translation>0 tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="260"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="895"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="923"/>
        <source>Downloading</source>
        <translation>Tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="263"/>
        <source>Completed</source>
        <translation>Amassar</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="266"/>
        <source>Trash</source>
        <translation>Wad nihel</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="330"/>
        <source>Downloader</source>
        <translation>Tashbeter</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="332"/>
        <source>Show main window</source>
        <translation>Liggasen fenestra tawwal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="334"/>
        <source>New task</source>
        <translation>Tashbet tawwal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="336"/>
        <source>Resume all</source>
        <translation>Liggasen awal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="338"/>
        <source>Pause all</source>
        <translation>Liggasen tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="614"/>
        <source>Are you sure you want to exit? 
Downloading tasks will be interrupted.</source>
        <translation>Tashbet? Amassar adawen tashbet yennawen.</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="615"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="725"/>
        <source> files</source>
        <translation> awen</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="895"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="923"/>
        <source>Downloading %1...</source>
        <translation>Dëkewen %1...</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="947"/>
        <source>No finished tasks</source>
        <translation>Wen adawen tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="960"/>
        <source>No deleted tasks</source>
        <translation>Wen adawen tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1073"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="2763"/>
        <source>Torrent file not exist or broken</source>
        <translation>Fichier torrent sib ñëmmar aw sib dëgë</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1073"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1659"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="2004"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1337"/>
        <source>Resume</source>
        <translation>Liggasen</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1344"/>
        <source>Pause</source>
        <translation>Liggasen tashbet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1351"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1366"/>
        <source>Download first</source>
        <translation>Dëkewen nes</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1373"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1390"/>
        <source>Download again</source>
        <translation>Dëkewen taw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1383"/>
        <source>Restore</source>
        <translation>Tërsëb</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1396"/>
        <source>Open</source>
        <translation>Tëfri</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1405"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1488"/>
        <source>Open folder</source>
        <translation>Tëfri dërdërt</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1426"/>
        <source>Rename</source>
        <translation>Tërsën</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1433"/>
        <source>Move to</source>
        <translation>Tëbës aw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1443"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1467"/>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1479"/>
        <source>Copy download link</source>
        <translation>Tëbës lïnk dëkew</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1454"/>
        <source>Delete</source>
        <translation>Tërsëb</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1460"/>
        <source>Permanently delete</source>
        <translation>Tërsëb tawer</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1496"/>
        <source>Delete all</source>
        <translation>Tërsëb as</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="1883"/>
        <source>The number of max. concurrent tasks reached. Other tasks will be queuing.</source>
        <translation>Nës sib ñëmmar tâsk tawer. Tâsk-taw ak tëbës aw tëfri ñ tâsk-aw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="2004"/>
        <source>Unable to parse the URL, please check</source>
        <translation>Sib ñëmmar tërsëb URL, wë chëf</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="2417"/>
        <source>Copied to clipboard</source>
        <translation>Tëbës ñ bëbël kënt</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/mainframe.cpp" line="2739"/>
        <source>View</source>
        <translation>Tëfri</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="47"/>
        <location filename="../src/src/ui/messagebox.cpp" line="123"/>
        <source>Warning</source>
        <translation>Tëfri wëwës</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="88"/>
        <location filename="../src/src/ui/messagebox.cpp" line="113"/>
        <location filename="../src/src/ui/messagebox.cpp" line="133"/>
        <source>Download Again</source>
        <translation>Dëkewen taw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="89"/>
        <source>Do you want to delete the downloaded files and download again?</source>
        <translation>Tëbës yë tërsëb fichier-taw aw dëkewen taw?</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="91"/>
        <source>These tasks already exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="93"/>
        <source>Delete the downloaded files and download again?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="106"/>
        <location filename="../src/src/ui/messagebox.cpp" line="275"/>
        <location filename="../src/src/ui/messagebox.cpp" line="333"/>
        <location filename="../src/src/ui/messagebox.cpp" line="348"/>
        <location filename="../src/src/ui/messagebox.cpp" line="364"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="110"/>
        <location filename="../src/src/ui/messagebox.cpp" line="170"/>
        <location filename="../src/src/ui/messagebox.cpp" line="191"/>
        <location filename="../src/src/ui/messagebox.cpp" line="209"/>
        <source>Cancel</source>
        <translation>Tëfri taw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="125"/>
        <source>Download error</source>
        <translation>Tëfri dëkew</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="137"/>
        <source>Delete All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="153"/>
        <source>Are you sure you want to delete this download task permanently?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="156"/>
        <source>Local files will be deleted at the same time.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="159"/>
        <source>Are you sure you want to delete this download task?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="163"/>
        <location filename="../src/src/ui/messagebox.cpp" line="165"/>
        <location filename="../src/src/ui/messagebox.cpp" line="190"/>
        <source>Delete local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="174"/>
        <source>Permanently Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="178"/>
        <source>Delete</source>
        <translation>Tërsëb</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="187"/>
        <source>Are you sure you want to delete all tasks in the trash?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="194"/>
        <source>Empty</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="204"/>
        <source>Please choose your action</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="206"/>
        <source>Exit</source>
        <translation>Talqin</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="206"/>
        <source>Minimize to system tray</source>
        <translation>Tawwal telsel gizlil</translation>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="208"/>
        <source>Do not ask again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="210"/>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="275"/>
        <source>The file name cannot contain a backslash (\) or slash (/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="329"/>
        <source>Permission denied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="331"/>
        <source>Please try another folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="344"/>
        <source>Path Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/messagebox.cpp" line="346"/>
        <source>The storage folder does not exist, please check and try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotificationsSettiingWidget</name>
    <message>
        <location filename="../src/src/ui/settings/notificationssettiingwidget.cpp" line="46"/>
        <source>Notify me when downloading finished or failed</source>
        <translation>Fessas mna tefass l-izawal tefass na tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/notificationssettiingwidget.cpp" line="53"/>
        <source>Change settings in &quot;Control Center - Notification - Downloader&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/notificationssettiingwidget.cpp" line="59"/>
        <source>Settings</source>
        <translation>Tashbet</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/include/ui/global.h" line="43"/>
        <source>Downloading</source>
        <translation>Tashbet</translation>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="44"/>
        <source>Waiting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="45"/>
        <source>Paused</source>
        <translation>Apsen</translation>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="46"/>
        <source>Error</source>
        <translation>Amskra</translation>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="47"/>
        <source>Completed</source>
        <translation>Kemzal</translation>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="48"/>
        <source>Removed</source>
        <translation>Sawal</translation>
    </message>
    <message>
        <location filename="../src/include/ui/global.h" line="49"/>
        <location filename="../src/include/ui/global.h" line="66"/>
        <source>Unknown</source>
        <translation>Mzaz</translation>
    </message>
    <message>
        <location filename="../src/src/downloader/main.cpp" line="86"/>
        <source>downloader</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/downloader/main.cpp" line="87"/>
        <location filename="../src/src/downloader/main.cpp" line="90"/>
        <source>Downloader</source>
        <translation>Dawlo</translation>
    </message>
    <message>
        <location filename="../src/src/downloader/main.cpp" line="91"/>
        <source>Downloader is a user-friendly download tool, supporting URLs and torrent files</source>
        <translation>Dawlo iwlal en neltiwlil iwlal iwlal, nesbit URL-wi i torrent.</translation>
    </message>
</context>
<context>
    <name>SearchResoultWidget</name>
    <message>
        <location filename="../src/src/ui/mainFrame/searchresoultwidget.cpp" line="66"/>
        <source>Completed</source>
        <translation>Kemzal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/searchresoultwidget.cpp" line="74"/>
        <source>Trash</source>
        <translation>Ksant</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/searchresoultwidget.cpp" line="82"/>
        <source>Downloading</source>
        <translation>Dawlo</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="385"/>
        <source>Basic</source>
        <translation>Awzawz</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="386"/>
        <source>Startup</source>
        <translation>Astarta</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="387"/>
        <source>Auto startup</source>
        <translation>Astarta tawwal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="388"/>
        <source>Resume downloading on startup</source>
        <translation>Iwaz dawlo tawwal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="389"/>
        <source>Download Directory</source>
        <translation>Diri dawlo</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="390"/>
        <source>1-Click Download</source>
        <translation>Dawlo 1-klik</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="391"/>
        <source>Create tasks directly</source>
        <translation>Tawzir taksen diri</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="392"/>
        <source>Close Main Window</source>
        <translation>Talqin fenen neltiwlil</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="393"/>
        <source>Minimize to system tray</source>
        <translation>Tawwal telsel gizlil</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="394"/>
        <source>Ask me always</source>
        <translation>Tazni men nwas</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="395"/>
        <source>Exit</source>
        <translation>Talqin</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="396"/>
        <source>Tasks</source>
        <translation>Taksen</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="397"/>
        <location filename="../src/src/ui/settings/settings.cpp" line="860"/>
        <source>Max. concurrent downloads</source>
        <translation>Dawlo mizizguz</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="398"/>
        <location filename="../src/src/ui/settings/settings.cpp" line="880"/>
        <source>Open files when completed</source>
        <translation>Tawiz fenen taksen kemzal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="399"/>
        <location filename="../src/src/ui/settings/settings.cpp" line="901"/>
        <source>Delete tasks without files</source>
        <translation>Talb taksen sawal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="400"/>
        <source>Downloads</source>
        <translation>Izawal</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="401"/>
        <source>Monitoring</source>
        <translation>Tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="402"/>
        <source>Applications</source>
        <translation>Aplikazzion</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="403"/>
        <source>Clipboard</source>
        <translation>Tal-Clip</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="404"/>
        <source>Browser</source>
        <translation>Tawizir</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="405"/>
        <source>Links Monitored</source>
        <translation>Hil yufessi</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="406"/>
        <source>BT Files</source>
        <translation>Fayl tiwizir</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="407"/>
        <source>Create new task when a torrent file downloaded</source>
        <translation>Tikrezz tishtan t-task tefass l-fayl torrent</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="408"/>
        <source>Create new task when opening a torrent file</source>
        <translation>Tikrezz tishtan t-task tefass l-fayl torrent tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="409"/>
        <source>MetaLink Files</source>
        <translation>Fayl MetaLink</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="410"/>
        <source>Create new task when a metalink file downloaded</source>
        <translation>Tikrezz tishtan t-task tefass l-fayl MetaLink</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="411"/>
        <source>Create new task when opening a metalink file</source>
        <translation>Tikrezz tishtan t-task tefass l-fayl MetaLink tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="412"/>
        <source>Notifications</source>
        <translation>Fessas</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="413"/>
        <source>Notify me when downloading finished or failed</source>
        <translation>Fessas mna tefass l-izawal tefass na tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="414"/>
        <source>Play a sound when downloading finished</source>
        <translation>Xell xemt l-izawal tefass</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="415"/>
        <source>Advanced</source>
        <translation>Adavans</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="416"/>
        <source>Shortcuts</source>
        <translation>Kortut</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="417"/>
        <source>Show main window when creating new task</source>
        <translation>Xell xelxel la fen xelxel l-bab t-tishtan t-task</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="418"/>
        <source>Cache</source>
        <translation>Cach</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="419"/>
        <location filename="../src/src/ui/settings/settings.cpp" line="921"/>
        <source>Move slow downloads to the end</source>
        <translation>Tatessi izawal tefass l-urta</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="420"/>
        <location filename="../src/src/ui/settings/settings.cpp" line="836"/>
        <source>Original address threads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="421"/>
        <source>Download Management</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="422"/>
        <source>Speed Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="514"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="535"/>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="557"/>
        <source>MetaLink</source>
        <translation>MetaLink</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="579"/>
        <source>Magnet URI scheme</source>
        <translation>Scheme URI Magnet</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="678"/>
        <source>When total speed less than</source>
        <translation>Ima l-ras l-ras l-urta tafess</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="678"/>
        <source>KB/s, increase concurrent tasks</source>
        <translation>KB/s, enkraz tasawuf t-task t-ta3dum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="690"/>
        <source>Total speed should be less than max. download speed</source>
        <translation>La sifla t-talji3 t-ta3dum t-ta3li3 mta3li3 sifla t-talji3 t-ta3dum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="760"/>
        <source>Download files less than</source>
        <translation>T-talji3 fil w3li3 lli t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="760"/>
        <source>MB first</source>
        <translation>MB t-ta3li3 lli</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="804"/>
        <source>Limit max. number of concurrent download resources</source>
        <translation>Bara n-ta3li3 t-ta3dum t-ta3li3 lli</translation>
    </message>
    <message>
        <location filename="../src/src/ui/settings/settings.cpp" line="941"/>
        <source>Larger disk cache will result in faster download speed 
and more resource consumption.</source>
        <translation>Iziz t-talji3 t-disk t-ta3li3 lli wassan sifla t-talji3 t-ta3dum t-ta3li3 wawwawta t-ta3li3 t-ta3dum</translation>
    </message>
</context>
<context>
    <name>TableDataControl</name>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="418"/>
        <source> &gt; 1 day</source>
        <translation> &gt; 1 diw</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="638"/>
        <source>Download failed</source>
        <translation>T-talji3 t-ta3li3 t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="639"/>
        <source>%1 download failed. Network error.</source>
        <translation>%1 t-talji3 t-ta3li3 t-ta3li3. T-ta3li3 t-ta3li3 t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="640"/>
        <source>Cancel</source>
        <translation>Annule</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="640"/>
        <source>View</source>
        <translation>Tafih</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="644"/>
        <source>Download completed</source>
        <translation>T-talji3 t-ta3li3 t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tabledatacontrol.cpp" line="645"/>
        <source>%1 download finished</source>
        <translation>%1 t-talji3 t-ta3li3 t-ta3li3</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="511"/>
        <source>Name</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="514"/>
        <source>Size</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="518"/>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="527"/>
        <source>Status</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="520"/>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="529"/>
        <source>Time finished</source>
        <translation>T-ta7allum t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="522"/>
        <location filename="../src/src/ui/mainFrame/tableModel.cpp" line="531"/>
        <source>Time deleted</source>
        <translation>T-ta7allum t-ta7allum</translation>
    </message>
</context>
<context>
    <name>TaskDelegate</name>
    <message>
        <location filename="../src/src/ui/createTask/taskdelegate.cpp" line="220"/>
        <location filename="../src/src/ui/createTask/taskdelegate.cpp" line="231"/>
        <source>Duplicate name</source>
        <translation>T-ta7allum t-ta7allum</translation>
    </message>
</context>
<context>
    <name>TaskModel</name>
    <message>
        <location filename="../src/src/ui/createTask/taskModel.cpp" line="146"/>
        <source>Name</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/taskModel.cpp" line="150"/>
        <source>Type</source>
        <translation>Tiflas</translation>
    </message>
    <message>
        <location filename="../src/src/ui/createTask/taskModel.cpp" line="152"/>
        <source>Size</source>
        <translation>Gad</translation>
    </message>
</context>
<context>
    <name>TopButton</name>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="91"/>
        <source>New task</source>
        <translation>T-ta3li3 t-ta3li3</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="98"/>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="173"/>
        <source>Pause</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="105"/>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="172"/>
        <source>Resume</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="112"/>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="158"/>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="166"/>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="174"/>
        <source>Delete</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="156"/>
        <source>Empty</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="157"/>
        <source>Restore</source>
        <translation>T-ta7allum</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="164"/>
        <source>Open folder</source>
        <translation>Ducen n dufra</translation>
    </message>
    <message>
        <location filename="../src/src/ui/mainFrame/topButton.cpp" line="165"/>
        <source>Open</source>
        <translation>Ducen</translation>
    </message>
</context>
</TS>